==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/include/connectors/sources/ext/soap/soap.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

require_once('include/connectors/sources/default/source.php');
require_once('include/nusoap/nusoap.php');
 
/**
 * ext_soap
 * This class is the soap implementation for the connector framework.
 * Connectors that use SOAP calls should subclass this class and provide
 * a getList and getItem method override to return results from the connector
 *
 */
abstract class ext_soap extends source {
	
	protected $_client;
	
	public function __construct(){
 		parent::__construct();
 	}
 	
 	/**
 	 * obj2array
 	 * Given an object, returns the object as an Array
 	 * 
 	 * @param $obj Object to convert to an array
 	 * @return $out Array reflecting the object's properties
 	 */
 	public function obj2array($obj) {
	  $out = array();
	  if(empty($obj)) {
	     return $out;	
	  }
	  
	  foreach ($obj as $key => $val) {
	    switch(true) {
	      case is_object($val):
	         $out[$key] = $this->obj2array($val);
	         break;
	      case is_array($val):
	         $out[$key] = $this->obj2array($val);
	         break;
	      default:
	        $out[$key] = $val;
	    }
	  }
  	  return $out;
	}
 	
 	public function __destruct(){
		parent::__destruct();
	}
}
?>

==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/include/connectors/sources/ext/soap/soap.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

require_once('include/connectors/sources/default/source.php');
require_once('include/nusoap/nusoap.php');
 
/**
 * ext_soap
 * This class is the soap implementation for the connector framework.
 * Connectors that use SOAP calls should subclass this class and provide
 * a getList and getItem method override to return results from the connector
 *
 */
abstract class ext_soap extends source {
	
	protected $_client;
	
	public function __construct(){
 		parent::__construct();
 	}
 	
 	/**
 	 * obj2array
 	 * Given an object, returns the object as an Array
 	 * 
 	 * @param $obj Object to convert to an array
 	 * @return $out Array reflecting the object's properties
 	 */
 	public function obj2array($obj) {
	  $out = array();
	  if(empty($obj)) {
	     return $out;	
	  }
	  
	  foreach ($obj as $key => $val) {
	    switch(true) {
	      case is_object($val):
	         $out[$key] = $this->obj2array($val);
	         break;
	      case is_array($val):
	         $out[$key] = $this->obj2array($val);
	         break;
	      default:
	        $out[$key] = $val;
	    }
	  }
  	  return $out;
	}
 	
 	public function __destruct(){
		parent::__destruct();
	}
}
?>
